main library

Classes

AnalyzerKit
Dart Analyzer plugin providing lint rules and quick fixes for analyzer_kit_annotation annotations.

Properties

plugin AnalyzerKit
The plugin singleton, instantiated by the Dart analysis server.
final