AnalyzerKit class

Dart Analyzer plugin providing lint rules and quick fixes for analyzer_kit_annotation annotations.

Registers 6 lint rules (one per annotation) and 6 corresponding quick fixes. Each lint rule detects when a class is annotated but missing the required methods, and the quick fix generates the missing code.

Registered Rules and Fixes

Rule Fix
DataClassRule AddDataClassMethods
CopyWithRule AddCopyWithMethod
OverrideToStringRule OverrideToStringMethod
OverrideEqualityRule OverrideEqualityMethods
SerializeRule AddSerializeMethod
DeserializeRule AddDeserializeMethod
Inheritance

Constructors

AnalyzerKit()

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
A user-visible name for this plugin, used for error-reporting and insights-reporting purposes.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register(PluginRegistry registry) → void
Registers analysis rules, quick fixes, and assists.
override
shutDown() FutureOr<void>
inherited
start() FutureOr<void>
Initializes any necessary start-up state that is required for this plugin to run.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited