start method

FutureOr<void> start()
inherited

Initializes any necessary start-up state that is required for this plugin to run.

This is called once by the plugin server, in PluginServer.initialize, per analysis context.

Implementation

FutureOr<void> start() {}