plugin top-level property

AnalyzerKit plugin
final

The plugin singleton, instantiated by the Dart analysis server.

This is the entry point for the analyzer_kit plugin. The analysis server discovers and loads this top-level plugin variable to register all lint rules and quick fixes.

Implementation

final plugin = AnalyzerKit();