AnalyzerKit class
Dart Analyzer plugin providing lint rules and quick fixes for analyzer_kit_annotation annotations.
Registers 6 lint rules (one per annotation) and 6 corresponding quick fixes. Each lint rule detects when a class is annotated but missing the required methods, and the quick fix generates the missing code.
Registered Rules and Fixes
| Rule | Fix |
|---|---|
DataClassRule |
AddDataClassMethods |
CopyWithRule |
AddCopyWithMethod |
OverrideToStringRule |
OverrideToStringMethod |
OverrideEqualityRule |
OverrideEqualityMethods |
SerializeRule |
AddSerializeMethod |
DeserializeRule |
AddDeserializeMethod |
- Inheritance
-
- Object
- Plugin
- AnalyzerKit
Constructors
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
register(
PluginRegistry registry) → void -
Registers analysis rules, quick fixes, and assists.
override
-
shutDown(
) → FutureOr< void> -
inherited
-
start(
) → FutureOr< void> -
Initializes any necessary start-up state that is required for this plugin
to run.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited